@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2021-03-19 10:23:13
-@LastEditTime: 2022-02-22 14:15:05
+@LastEditTime: 2022-02-22 15:41:53
 @LastEditors: ChenCheng
 :Description: 奖品
 """
@@ -105,11 +105,14 @@ class PrizeListHandler(ClientBaseHandler):
         prize_sum_dict = act_prize_ex_model.get_dict("module_id=%s and is_del=0 and is_release=1 and yfs_type=1", field="CAST(SUM(probability) AS SIGNED) AS prize_sum_probability", params=module_id)
         prize_sum_probability = prize_sum_dict["prize_sum_probability"] if prize_sum_dict["prize_sum_probability"] else 0
 
+        # 叠叠赏列表
+        special_dd_list = act_prize_ex_model.get_dict_list("module_id=%s and is_del=0 and is_release=1 and yfs_type=3", order_by="dd_open_step ASC", field=field, params=module_id)
         for act_prize in act_prize_list:
             act_prize["chance"] = round(act_prize["probability"] / prize_sum_probability * 100, 2) if prize_sum_probability else 0
             act_prize["hand_out"] = act_prize["prize_total"] - act_prize["surplus"]
 
         page_info = PageInfo(page_index, page_size, total, act_prize_list)
+        page_info.special_dd_list = special_dd_list
 
         return self.response_json_success(page_info)
 
@@ -197,7 +200,7 @@ class BackpackRedHandler(ClientBaseHandler):
             return self.response_json_success(1)
         else:
             return self.response_json_success(0)
-            
+
 
 class UserPrizeListHandler(ClientBaseHandler):
     """
